@@ -13,7 +13,7 @@ Created on Thu May 15 12:12:40 2014
 import numpy as np
 from sympy.simplify import simplify
 from sympy.physics.quantum.operator import HermitianOperator
-from ncpol2sdpa import SdpRelaxation
+from ncpol2sdpa import SdpRelaxation, write_to_sdpa
 
 W = np.diag(np.ones(8), 1) + np.diag(np.ones(7), 2) + np.diag([1, 1], 7) + \
     np.diag([1], 8)
@@ -32,5 +32,6 @@ for i in range(n):
 objective = simplify(np.dot(x, np.dot(Q, np.transpose(x))))
 
 sdpRelaxation = SdpRelaxation(x)
-sdpRelaxation.get_relaxation(objective, [], equalities, {}, 1)
-sdpRelaxation.write_to_sdpa('max_cut.dat-s')
+sdpRelaxation.get_relaxation(objective, [], equalities, {}, 1,
+                             removeequalities=True)
+write_to_sdpa(sdpRelaxation, 'max_cut.dat-s')
