@@ -20,16 +20,35 @@ else:
 from .nc_utils import apply_substitutions, build_monomial, \
     pick_monomials_up_to_degree, ncdegree, \
     separate_scalar_factor, flatten, build_permutation_matrix, \
-    simplify_polynomial, save_monomial_dictionary, get_monomials
+    simplify_polynomial, save_monomial_dictionary, get_monomials, unique
 from .sdpa_utils import convert_row_to_sdpa_index
 
-
 class SdpRelaxation(object):
 
     """Class for obtaining sparse SDP relaxation.
     """
+    hierarchy_types = ["npa", "nieto-silleras", "moroder"]
+
+    def __init__(self, variables, verbose=0, hierarchy="npa", normalized=True):
+        """Constructor for the class.
+
+        Arguments:
+        variables -- commutative or noncommutative, Hermitian or nonhermiatian
+                     variables, possibly a list of list of variables if the
+                     hierarchy is not NPA.
+        verbose -- level of verbosity:
+                       0: quiet
+                       1: verbose
+                       2: debug level
+        hierarchy -- type of hierarchy (default: "npa"):
+                       "npa": the standard NPA hierarchy (doi:10.1137/090760155)
+                       "nieto-silleras": doi:10.1088/1367-2630/16/1/013035
+                       "moroder": 10.1103/PhysRevLett.111.030501
+        normalized -- normalization of states over which the optimization
+                      happens. Turn it off if further processing is done on the
+                      SDP matrix, for instance, in MATLAB.
+        """
 
-    def __init__(self, variables, verbose=0, independent_algebras=False):
         self.monomial_substitutions = {}
         self.monomial_dictionary = {}
         self.n_vars = 0
@@ -39,11 +58,21 @@ class SdpRelaxation(object):
         self.variables = []
         self.verbose = verbose
         self.localization_order = []
-        self.independent_algebras = independent_algebras
+        self.normalized = normalized
+        if hierarchy in self.hierarchy_types:
+            self.hierarchy = hierarchy
+        else:
+            raise Exception('Not allowed hierarchy type:', hierarchy)
         if isinstance(variables, list):
             self.variables = variables
         else:
             self.variables = [variables]
+        self.is_hermitian_variables = True
+        # Check hermicity of all variables
+        for var in flatten(self.variables):
+            if not var.is_hermitian:
+                self.is_hermitian_variables = False
+                break
 
     def __get_index_of_monomial(self, element, enablesubstitution=True):
         """Returns the index of a monomial.
@@ -142,13 +171,71 @@ class SdpRelaxation(object):
             # previous variable to denote this entry in the matrix
             k = self.monomial_dictionary[monomial]
         except KeyError:
-            # Otherwise we define a new entry in the associated
-            # array recording the monomials, and add an entry in
-            # the moment matrix
-            k = n_vars + 1
-            self.monomial_dictionary[monomial] = k
+            # An extra round of substitutions is granted on the conjugate of
+            # the monomial if all the variables are Hermitian
+            need_new_variable = True
+            if self.is_hermitian_variables:
+                daggered_monomial = \
+                  apply_substitutions(Dagger(monomial),
+                                      self.monomial_substitutions)
+                try:
+                    k = self.monomial_dictionary[daggered_monomial]
+                    need_new_variable = False
+                except KeyError:
+                    need_new_variable = True
+            if need_new_variable:
+                # Otherwise we define a new entry in the associated
+                # array recording the monomials, and add an entry in
+                # the moment matrix
+                k = n_vars + 1
+                self.monomial_dictionary[monomial] = k
         return k
 
+    def __generate_moroder_moment_matrix(self, n_vars, block_index,
+                                         monomialsA, monomialsB):
+        """Generate the moment matrix of monomials.
+
+        Arguments:
+        n_vars -- current number of variables
+        block_index -- current block index in the SDP matrix
+        monomials -- |W_d| set of words of length up to the relaxation level
+        """
+        row_offset = 0
+        if block_index > 0:
+            for block_size in self.block_struct[0:block_index]:
+                row_offset += block_size ** 2
+        N = len(monomialsA)*len(monomialsB)
+        # We process the M_d(u,w) entries in the moment matrix
+        for rowA in range(len(monomialsA)):
+            for columnA in range(rowA, len(monomialsA)):
+                for rowB in range(len(monomialsB)):
+                    start_columnB = 0
+                    if rowA == columnA:
+                        start_columnB = rowB
+                    for columnB in range(start_columnB, len(monomialsB)):
+                        monomial = Dagger(monomialsA[rowA]) * \
+                                   monomialsA[columnA] * \
+                                   Dagger(monomialsB[rowB]) * \
+                                   monomialsB[columnB]
+                        # Apply the substitutions if any
+                        monomial = apply_substitutions(monomial,
+                                                       self.monomial_substitutions)
+                        if monomial == 1 and self.normalized:
+                            self.F_struct[row_offset + rowA * N*len(monomialsB) +
+                                          rowB * N +
+                                          columnA * len(monomialsB) + columnB, 0] = 1
+
+                        elif monomial != 0:
+                            k = self.__process_monomial(monomial, n_vars)
+                            if k > n_vars:
+                                n_vars = k
+                            # We push the entry to the moment matrix
+                            self.F_struct[row_offset + rowA * N*len(monomialsB) +
+                                          rowB * N +
+                                          columnA * len(monomialsB) + columnB, k] = 1
+        return n_vars, block_index + 1
+
+
     def __generate_moment_matrix(self, n_vars, block_index, monomials):
         """Generate the moment matrix of monomials.
 
@@ -169,15 +256,15 @@ class SdpRelaxation(object):
                 # Apply the substitutions if any
                 monomial = apply_substitutions(monomial,
                                                self.monomial_substitutions)
-                if monomial == 1:
-                    if not self.independent_algebras:
-                        self.F_struct[row_offset + row * len(monomials) +
-                                      column, 0] = 1
-                    else:
+                if monomial == 1 and self.normalized:
+                    if self.hierarchy == "nieto-silleras":
                         k = n_vars + 1
                         n_vars = k
                         self.F_struct[row_offset + row * len(monomials) +
                                       column, k] = 1
+                    else:
+                        self.F_struct[row_offset + row * len(monomials) +
+                                      column, 0] = 1
                 elif monomial != 0:
                     k = self.__process_monomial(monomial, n_vars)
                     if k > n_vars:
@@ -204,7 +291,7 @@ class SdpRelaxation(object):
                 block_index - initial_block_index - 1]
             monomials = \
                 pick_monomials_up_to_degree(all_monomials, localization_order)
-
+            monomials = unique(monomials)
             # Process M_y(gy)(u,w) entries
             for row in range(len(monomials)):
                 for column in range(row, len(monomials)):
@@ -266,8 +353,11 @@ class SdpRelaxation(object):
     def __calculate_block_structure(self, monomial_sets, inequalities, level):
         """Calculates the block_struct array for the output file.
         """
-        for monomials in monomial_sets:
-            self.block_struct.append(len(monomials))
+        if  self.hierarchy == "moroder":
+            self.block_struct.append(len(monomial_sets[0])*len(monomial_sets[1]))
+        else:
+            for monomials in monomial_sets:
+                self.block_struct.append(len(monomials))
         for ineq in inequalities:
             # Find the order of the localizing matrix
             ineq_order = ncdegree(ineq)
@@ -280,6 +370,8 @@ class SdpRelaxation(object):
             localizing_monomials = \
                 pick_monomials_up_to_degree(flatten(monomial_sets),
                                             localization_order)
+            if self.hierarchy == "nieto-silleras":
+                localizing_monomials = [1]
             self.block_struct.append(len(localizing_monomials))
 
     def get_relaxation(self, obj, inequalities, equalities,
@@ -300,11 +392,15 @@ class SdpRelaxation(object):
                             solving the linear equations
         extramonomials -- monomials to be included, on top of the requested
                           level of relaxation
+        target -- target writing routine (default: "sdpa"):
+                     "sdpa": produces a sparse SDPA problem
+                     "picos": further processing is possible with PICOS
         """
+
         self.monomial_substitutions = monomial_substitutions
         # Generate monomials and remove substituted ones
         monomial_sets = []
-        if self.independent_algebras:
+        if not self.hierarchy == "npa":
             k = 0
             for variables in self.variables:
                 extramonomials_ = None
@@ -328,18 +424,23 @@ class SdpRelaxation(object):
                 inequalities.append(-equality)
 
         self.__calculate_block_structure(monomial_sets, inequalities, level)
-        if self.independent_algebras:
+        if self.hierarchy == "nieto-silleras":
             self.block_struct.append(2)
 
         self.n_vars = 0
-        for monomials in monomial_sets:
-            n_monomials = len(monomials)
+        if not self.hierarchy == "moroder":
+            for monomials in monomial_sets:
+                n_monomials = len(monomials)
 
-            # The minus one compensates for the constant term in the
-            # top left corner of the moment matrix
+                # The minus one compensates for the constant term in the
+                # top left corner of the moment matrix
+                self.n_vars += int(n_monomials * (n_monomials + 1) / 2)
+                if self.hierarchy == "npa":
+                    self.n_vars -= 1
+        else:
+            n_monomials = len(monomial_sets[0])*len(monomial_sets[1])
             self.n_vars += int(n_monomials * (n_monomials + 1) / 2)
-            if not self.independent_algebras:
-                self.n_vars -= 1
+            self.n_vars -= 1
 
         n_rows = 0
         for block_size in self.block_struct:
@@ -352,13 +453,19 @@ class SdpRelaxation(object):
        # Generate moment matrices
         new_n_vars, block_index = 0, 0
         var_offsets = [new_n_vars]
-        for monomials in monomial_sets:
+        if self.hierarchy == "moroder":
             new_n_vars, block_index = \
-                self.__generate_moment_matrix(
-                    new_n_vars,
-                    block_index,
-                    monomials)
-            var_offsets.append(new_n_vars)
+                self.__generate_moroder_moment_matrix(new_n_vars, block_index,
+                                                      monomial_sets[0],
+                                                      monomial_sets[1])
+        else:
+            for monomials in monomial_sets:
+                new_n_vars, block_index = \
+                    self.__generate_moment_matrix(
+                        new_n_vars,
+                        block_index,
+                        monomials)
+                var_offsets.append(new_n_vars)
         self.n_vars = new_n_vars
         # The initial estimate for the size of F_struct was overly
         # generous. We correct the size here.
@@ -381,8 +488,7 @@ class SdpRelaxation(object):
             self.__get_facvar(
                 simplify_polynomial(
                     obj,
-                    self.monomial_substitutions)))[
-            1:]
+                    self.monomial_substitutions)))[1:]
         # Process inequalities
         if self.verbose > 0:
             print(('Processing %d inequalities...' % len(inequalities)))
@@ -393,7 +499,7 @@ class SdpRelaxation(object):
             A = self.__process_equalities(equalities, flatten(monomial_sets),
                                           level)
             self.__remove_equalities(equalities, A)
-        if self.independent_algebras:
+        if self.hierarchy == "nieto-silleras"  and self.normalized:
             self.F_struct[-1, 0] = -1
             self.F_struct[-4, 0] = 1
             for var in var_offsets[:-1]:
